@@ -23,7 +23,7 @@ class TestExamples(unittest.TestCase):
         self._run("TAP")
 
     def test_roman_numerals(self):
-        self._run("romanNumerals")
+        self._run("roman_numerals")
 
     def test_sexp_parser(self):
         self._run("sexpParser")
@@ -60,3 +60,6 @@ class TestExamples(unittest.TestCase):
 
     def test_email_parser(self):
         self._run("email_address_parser")
+
+    def test_mongodb_query_parser(self):
+        self._run("mongodb_query_expression")
